@@ -75,9 +75,9 @@ def check_fed_model(save_dir,keys,test_acc=None,test_loss=None,EpochCount=None):
         if avg_model:
             for key in keys:
                 try:
-                    model=torch.load(os.path.join(save_dir,key))
+                    # model=torch.load(os.path.join(save_dir,key))
                     torch.save(avg_model,os.path.join(save_dir,'%s_model'%(key)))
-                    os.remove(os.path.join(save_dir,key))
+                    # os.remove(os.path.join(save_dir,key))
                 except:
                     pass
     return result
@@ -97,7 +97,9 @@ def check_client_all(save_dir,keys):
     result=1
     try:
         for key in keys:
+            print('start load',key)
             model=torch.load(os.path.join(save_dir,key))
+            print('end load',key)
         result=3
     except:
         pass
