@@ -9,8 +9,9 @@ from . import Util
 from FModel.models import Clients
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 import subprocess
-# save_dir=os.path.join(BASE_DIR, 'static', 'modelfile')
-save_dir=subprocess.getoutput("pwd")
+save_dir=os.path.join(BASE_DIR, 'static', 'modelfile')
+# save_dir=subprocess.getoutput("pwd")
+# print(save_dir)
 def index(request): 
     context= {}
     context['clients']=Util.getClients()
@@ -32,7 +33,7 @@ def send_model(request):
         test_acc=request.POST.get('acc')
         test_loss=request.POST.get('loss')
         modelfile=request.FILES.get('file')
-        with  open(os.path.join(BASE_DIR, 'static', 'modelfile',key), 'wb') as f:
+        with  open(os.path.join(save_dir,key), 'wb') as f:
             for chunk in modelfile.chunks():
                 f.write(chunk)
         ncl=Clients.objects.filter(Key=key).first()
@@ -42,6 +43,7 @@ def send_model(request):
         keys=[cl.Key for cl in Clients.objects.filter(Status=1)]
         result=Util.check_fed_model(save_dir,keys,test_acc,test_loss,10)
         context['result']=result
+        print('send_model',context)
     return HttpResponse(json.dumps(context),content_type="application/json")
 @csrf_exempt
 def get_status(request):
@@ -50,14 +52,21 @@ def get_status(request):
         key=request.POST.get('key')
         keys=[cl.Key for cl in Clients.objects.filter(Status=1)]
         context['modelurl']=''
-        context['result']=Util.check_client_all(save_dir,keys)
         context['clientstatus']=Util.check_client(save_dir,key)
-        # if int(context['result'])==3:
-        if os.path.exists(os.path.join(save_dir,'%s_model'%(key))):
-            os.rename(os.path.join(save_dir,'%s_model'%(key)),os.path.join(save_dir,'%s_modelb'%(key)))
-            context['modelurl']=os.path.join(save_dir,'%s_modelb'%(key)).replace(BASE_DIR,'')
         context['result']=Util.check_client_all(save_dir,keys)
-        context['clientstatus']=Util.check_client(save_dir,key)
+        print('context[\'result\']',context['result'])
+        if int(context['result'])==3:
+            if os.path.exists(os.path.join(save_dir,'%s_model'%(key))):
+                os.rename(os.path.join(save_dir,'%s_model'%(key)),os.path.join(save_dir,'%s_modelb'%(key)))
+                context['modelurl']=os.path.join(save_dir,'%s_modelb'%(key)).replace(BASE_DIR,'')
+                try:
+                    model=torch.load(os.path.join(save_dir,key))
+                    os.remove(os.path.join(save_dir,key))
+                except:
+                    pass 
+            else:
+                Util.check_fed_model(save_dir,keys,0,0,10)
+        print(context)
         # Util.addtasklog(ut.save_dir,'get_status',taskid,clientid,'result',context['result'],context['modelurl'],context['clienttrain'])
     return HttpResponse(json.dumps(context),content_type="application/json") 
 
